Literature
==========

   References managed in public `Zotero Library <https://www.zotero.org/groups/4730892/pycontrails/library>`__


.. only:: html or text

   .. rubric:: References

.. bibliography::
   :cited:
